@@ -89,25 +89,23 @@ inflate <- function(pkg = ".", flat_file,
 
 
   # If flat_file empty
-  if (
-    requireNamespace("rstudioapi") &&
-      rstudioapi::isAvailable() &&
-      rstudioapi::hasFun("documentPath")
-  ) {
+  if (missing(flat_file) && requireNamespace("rstudioapi") && rstudioapi::isAvailable() &&
+      rstudioapi::hasFun("documentPath") ) {
     current_file <- rstudioapi::documentPath()
-    if (missing(flat_file) & grepl("^flat.*[.]Rmd$", basename(current_file))) {
+    if (!is.null(current_file) && grepl("^flat.*[.](R|r|q)md$", basename(current_file))) {
       if (overwrite == "ask") {
-        sure <- paste(
-          "The current file will be inflated:\n",
-          current_file, ".\n",
-          "Are you sure this is what you planned? (y/n)\n"
-        )
+        sure <- paste0("You did not specify parameter 'flat_file'. The current file will be inflated:\n",
+                      current_file, ".\n",
+                      "With vignette name: ", vignette_name, "\n",
+                      "Are you sure this is what you planned? (y/n)\n")
         do_it <- readline(sure) == "y"
-      } else {
+      }
+      else {
         do_it <- isTRUE(overwrite)
       }
       if (do_it) {
-        message("The current file will be inflated: ", current_file)
+        message("The current file will be inflated: ",
+                current_file)
         flat_file <- current_file
       }
     }
@@ -178,7 +176,7 @@ inflate <- function(pkg = ".", flat_file,
       file.remove(vignette_path)
     } else {
       stop(
-        "Vignette already exists, anwser 'yes' to the previous question",
+        "Vignette already exists, answer 'yes' to the previous question",
         " or set inflate(..., overwrite = 'yes') to always overwrite."
       )
     }
